Accepting request 576776 from LibreOffice:Factory

- Make sure we execute everything with python3
  * 0001-Use-PYTHON_FOR_BUILD-instead-of-calling-python-direc.patch
- Bump version of bundled gpgme to 1.9.0

- Version update to 6.0.1.1:
  * various fixes all around
  * Fixes data exposure bsc#1080249 CVE-2018-1055 CVE-2018-6871
- Bump the version of libgpg-error
- Drop the libreoffice-poppler-0.62.patch merged upstream

OBS-URL: https://build.opensuse.org/request/show/576776
OBS-URL: https://build.opensuse.org/package/show/openSUSE:Factory/libreoffice?expand=0&rev=146
This commit is contained in:
Dominique Leuenberger 2018-02-15 12:23:39 +00:00 committed by Git OBS Bridge
commit c411917c83
14 changed files with 84 additions and 59 deletions

View File

@ -0,0 +1,40 @@
From 5c4c83dd7ee9145408d80dbac606547c8006ad2a Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?Tom=C3=A1=C5=A1=20Chv=C3=A1tal?= <tchvatal@suse.com>
Date: Tue, 13 Feb 2018 10:57:54 +0100
Subject: [PATCH] Use PYTHON_FOR_BUILD instead of calling python directly
Change-Id: I85ff669c3cfd6d9b3284972cfa1d8a805ea3b6d4
---
postprocess/CustomTarget_images.mk | 2 +-
testtools/source/bridgetest/pyuno/makefile.mk | 2 +-
2 files changed, 2 insertions(+), 2 deletions(-)
diff --git a/postprocess/CustomTarget_images.mk b/postprocess/CustomTarget_images.mk
index 603c73d522d4..871c7bd6470c 100644
--- a/postprocess/CustomTarget_images.mk
+++ b/postprocess/CustomTarget_images.mk
@@ -33,7 +33,7 @@ $(packimages_DIR)/%.zip : \
$(call gb_Output_announce,$(subst $(WORKDIR)/,,$@),$(true),PRL,2)
$(call gb_Helper_abbreviate_dirs, \
ILSTFILE=$(call var2file,$(shell $(gb_MKTEMP)),100,$(filter %.ilst,$^)) && \
- $(PYTHON) $(SRCDIR)/solenv/bin/pack_images.py \
+ $(PYTHON_FOR_BUILD) $(SRCDIR)/solenv/bin/pack_images.py \
$(if $(DEFAULT_THEME),\
-g $(packimages_DIR) -m $(packimages_DIR) -c $(packimages_DIR),\
-g $(SRCDIR)/icon-themes/$(subst images_,,$*) -m $(SRCDIR)/icon-themes/$(subst images_,,$*) -c $(SRCDIR)/icon-themes/$(subst images_,,$*) \
diff --git a/testtools/source/bridgetest/pyuno/makefile.mk b/testtools/source/bridgetest/pyuno/makefile.mk
index 5dbd0038f009..112be23c9ce8 100644
--- a/testtools/source/bridgetest/pyuno/makefile.mk
+++ b/testtools/source/bridgetest/pyuno/makefile.mk
@@ -46,7 +46,7 @@ REGEXC=$(DLLDEST)$/regcomp$(EXECPOST)
.IF "$(SYSTEM_PYTHON)"!="YES"
PYTHON=$(AUGMENT_LIBRARY_PATH) $(WRAPCMD) $(SOLARBINDIR)/python
.ELSE # "$(SYSTEM_PYTHON)"!="YES"
-PYTHON=$(AUGMENT_LIBRARY_PATH) $(WRAPCMD) python
+PYTHON=$(AUGMENT_LIBRARY_PATH) $(WRAPCMD) $(PYTHON_FOR_BUILD)
.ENDIF # "$(SYSTEM_PYTHON)"!="YES"
.IF "$(OS)"=="WNT"
PYTHONPATH:=$(SOLARLIBDIR)$/pyuno;$(PWD);$(SOLARLIBDIR);$(SOLARLIBDIR)$/python;$(SOLARLIBDIR)$/python$/lib-dynload
--
2.16.1

View File

@ -1,3 +0,0 @@
version https://git-lfs.github.com/spec/v1
oid sha256:596097257c2ce22e747741f8ff3d7e24f6e26231fa198a41b2a072e62d1e5d33
size 1298407

3
gpgme-1.9.0.tar.bz2 Normal file
View File

@ -0,0 +1,3 @@
version https://git-lfs.github.com/spec/v1
oid sha256:1b29fedb8bfad775e70eafac5b0590621683b2d9869db994568e6401f4034ceb
size 1344222

View File

@ -1,3 +0,0 @@
version https://git-lfs.github.com/spec/v1
oid sha256:4c4bcbc90116932e3acd37b37812d8653b1b189c1904985898e860af818aee69
size 798096

View File

@ -0,0 +1,3 @@
version https://git-lfs.github.com/spec/v1
oid sha256:4f93aac6fecb7da2b92871bb9ee33032be6a87b174f54abf8ddf0911a22d29d2
size 813060

View File

@ -1,3 +0,0 @@
version https://git-lfs.github.com/spec/v1
oid sha256:dc2171845ec19d5a0cece2c0052172011b2ec435cac80cb47637f2af94e19e3d
size 203284136

View File

@ -0,0 +1,3 @@
version https://git-lfs.github.com/spec/v1
oid sha256:8f802a9c6ed645218a07b34530113f357b694f2653d734fe8a9003068b5670a9
size 203420780

View File

@ -1,3 +0,0 @@
version https://git-lfs.github.com/spec/v1
oid sha256:9f4750a5dc087c1b700dc200ffe614932e4f854c185084207b79f5a8e2968442
size 2972556

View File

@ -0,0 +1,3 @@
version https://git-lfs.github.com/spec/v1
oid sha256:4466ffc014f5dd3bc7b2676c18e25687c95b00f0379b61c8db988091a4a5d647
size 2972872

View File

@ -1,31 +0,0 @@
Index: libreoffice-6.0.0.1/sdext/source/pdfimport/xpdfwrapper/pdfioutdev_gpl.cxx
===================================================================
--- libreoffice-6.0.0.1.orig/sdext/source/pdfimport/xpdfwrapper/pdfioutdev_gpl.cxx
+++ libreoffice-6.0.0.1/sdext/source/pdfimport/xpdfwrapper/pdfioutdev_gpl.cxx
@@ -32,10 +32,12 @@
#pragma warning(push, 1)
#endif
// sigh, UTF8.h was removed in poppler-0.21.0 and put back in 0.21.1
// FIXME: we can't use #if POPPLER_CHECK_VERSION(0, 21, 0) && !POPPLER_CHECK_VERSION(0, 21, 1)
// because the internal poppler does not provide poppler-version.h and the macro always returns 0
-#if POPPLER_CHECK_VERSION(0, 21, 1)
+#if POPPLER_CHECK_VERSION(0, 62, 0)
+#include <UnicodeMapFuncs.h>
+#elif POPPLER_CHECK_VERSION(0, 21, 1)
#include <UTF8.h>
#elif POPPLER_CHECK_VERSION(0, 21, 0)
#include "UTF.h"
@@ -913,7 +915,11 @@ void PDFOutDev::drawChar(GfxState *state
);
// silence spurious warning
+#if POPPLER_CHECK_VERSION(0, 62, 0)
+ (void)&mapUTF16;
+#else
(void)&mapUCS2;
+#endif
char buf[9];
for( int i=0; i<uLen; ++i )

View File

@ -1,3 +0,0 @@
version https://git-lfs.github.com/spec/v1
oid sha256:8afeb5cbb608e451a9b1acaef87601323faf403b490bd188edb5ddeedd60587e
size 139020268

View File

@ -0,0 +1,3 @@
version https://git-lfs.github.com/spec/v1
oid sha256:52a2ce93d87f0c248d08685f9eb37fd11c8e0196f8795fe516dd156ecdd21047
size 139061168

View File

@ -1,3 +1,19 @@
-------------------------------------------------------------------
Mon Feb 12 09:24:51 UTC 2018 - tchvatal@suse.com
- Make sure we execute everything with python3
* 0001-Use-PYTHON_FOR_BUILD-instead-of-calling-python-direc.patch
- Bump version of bundled gpgme to 1.9.0
-------------------------------------------------------------------
Fri Feb 9 11:59:11 UTC 2018 - tchvatal@suse.com
- Version update to 6.0.1.1:
* various fixes all around
* Fixes data exposure bsc#1080249 CVE-2018-1055 CVE-2018-6871
- Bump the version of libgpg-error
- Drop the libreoffice-poppler-0.62.patch merged upstream
-------------------------------------------------------------------
Fri Feb 2 11:30:20 UTC 2018 - tchvatal@suse.com

View File

@ -22,8 +22,8 @@
%define numbertext_version 0.9.5
# Urls
%define external_url http://dev-www.libreoffice.org/src/
#%define tarball_url http://download.documentfoundation.org/libreoffice/src/6.0.0
%define tarball_url http://dev-builds.libreoffice.org/pre-releases/src/
%define tarball_url http://download.documentfoundation.org/libreoffice/src/6.0.1
#%define tarball_url http://dev-builds.libreoffice.org/pre-releases/src/
# Enable the kde integration on openSUSE only
%if 0%{?is_opensuse}
%bcond_without kdeintegration
@ -46,7 +46,7 @@
%bcond_with system_gpgme
%endif
Name: libreoffice
Version: 6.0.0.3
Version: 6.0.1.1
Release: 0
Summary: A Free Office Suite (Framework)
License: LGPL-3.0+ and MPL-2.0+
@ -64,8 +64,8 @@ Source402: %{external_url}/b7cae45ad2c23551fd6ccb8ae2c1f59e-numbertext_%{nu
Source450: %{external_url}/1f467e5bb703f12cbbb09d5cf67ecf4a-converttexttonumber-1-5-0.oxt
Source452: %{external_url}/90401bca927835b6fbae4a707ed187c8-nlpsolver-0.9.tar.bz2
# GPGME bundle list
Source1000: %{external_url}/gpgme-1.8.0.tar.bz2
Source1001: %{external_url}/libgpg-error-1.26.tar.bz2
Source1000: %{external_url}/gpgme-1.9.0.tar.bz2
Source1001: %{external_url}/libgpg-error-1.27.tar.bz2
Source1002: %{external_url}/libassuan-2.4.3.tar.bz2
# Internal bundled stuff we can't remove
# To build this we would pull cygwin; not worth it
@ -87,10 +87,10 @@ Source2008: %{external_url}/pdfium-3235.tar.bz2
Patch1: scp2-user-config-suse.diff
# do not use the broken help; unopkg complained about it when registering extensions
# FIXME: the right fix is to compile the help and produce the .db_, .ht_, and other files
Patch4: nlpsolver-no-broken-help.diff
Patch5: mediawiki-no-broken-help.diff
Patch6: kde5-configure-checks.patch
Patch7: libreoffice-poppler-0.62.patch
Patch2: nlpsolver-no-broken-help.diff
Patch3: mediawiki-no-broken-help.diff
Patch4: kde5-configure-checks.patch
Patch5: 0001-Use-PYTHON_FOR_BUILD-instead-of-calling-python-direc.patch
# try to save space by using hardlinks
Patch990: install-with-hardlinks.diff
BuildRequires: %{name}-share-linker
@ -877,10 +877,10 @@ Provides additional %{langname} translations and resources for %{project}. \
%if 0%{?suse_version} < 1330
%patch1
%endif
@@ -32,10 +32,12 @@
#pragma warning(push, 1)
#endif
-// sigh, UTF8.h was removed in poppler-0.21.0 and put back in 0.21.1
+// sigh, UTF8.h was removed in poppler-0.21.0 and put back in 0.21.1, then renamed to UnicodeMapFuncs.h in 0.62.0
// FIXME: we can't use #if POPPLER_CHECK_VERSION(0, 21, 0) && !POPPLER_CHECK_VERSION(0, 21, 1)
// because the internal poppler does not provide poppler-version.h and the macro always returns 0
%patch4
%patch5
%patch6 -p1
%patch7 -p1
%patch2
%patch3
%patch4 -p1
%patch5 -p1
%patch990 -p1
# Disable some of the failing tests (some are random)